@@ -40,6 +40,8 @@ has 'source_address' => ( is => 'ro', isa => 'Maybe[Str]', lazy => 1, default =>
 has 'fake_delegations' => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
 has 'fake_ds'          => ( is => 'ro', isa => 'HashRef', default => sub { {} } );
 
+has 'blacklisted' => ( is => 'rw', isa => 'HashRef', default => sub { {} }, required => 1 );
+
 ###
 ### Variables
 ###
@@ -279,14 +281,26 @@ sub _query {
     }
 
     my $before = time();
-    my $res = eval { $self->dns->query( "$name", $type, $href->{class} ) };
-    if ( $@ ) {
-        my $msg = "$@";
-        chomp( $msg );
+    my $res;
+    if ( $self->blacklisted->{$flags{usevc}}{$flags{dnssec}} ) {
         Zonemaster->logger->add(
-            LOOKUP_ERROR => { message => $msg, ns => "$self", name => "$name", type => $type, class => $href->{class} }
+            IS_BLACKLISTED => { message => "Server transport has been blacklisted due to previous failure", ns => "$self", name => "$name", type => $type, class => $href->{class}, proto => $flags{usevc} ? q{TCP} : q{UDP}, dnssec => $flags{dnssec} }
         );
     }
+    else {
+        $res = eval { $self->dns->query( "$name", $type, $href->{class} ) };
+        if ( $@ ) {
+            my $msg = "$@";
+            chomp( $msg );
+            Zonemaster->logger->add(
+                LOOKUP_ERROR => { message => $msg, ns => "$self", name => "$name", type => $type, class => $href->{class} }
+            );
+            $self->blacklisted->{$flags{usevc}}{$flags{dnssec}} = 1;
+            if ( ! $flags{dnssec} ) {
+                $self->blacklisted->{$flags{usevc}}{!$flags{dnssec}} = 1;
+            }
+        }
+    }
     push @{ $self->times }, ( time() - $before );
 
     # Reset to defaults
